@@ -10,29 +10,26 @@ case $1 in
 		        echo "Soft" 
 				sed -i -e s'/PatternIncomingCall=.*/PatternIncomingCall=1;3;0;0;10;800;0;800;45/' -e s'/PatternIncomingMessage=.*/PatternIncomingMessage=3;3;2;2;10;800;0;800;45/' -e s'/PatternChatAndEmail=.*/PatternChatAndEmail=4;3;1;1;5;450;0;75;45/' /etc/mce/mce.ini
 				echo "Soft vibration profile Loaded" 
-				run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Rebooting!"
-                /sbin/reboot 
 				;;
 		'-'[Hh] ) 
 		        echo "Hard" 
 				sed -i -e s'/PatternIncomingCall=.*/PatternIncomingCall=1;3;0;0;100;1200;0;1000;250/' -e s'/PatternIncomingMessage=.*/PatternIncomingMessage=3;3;2;2;100;900;0;1000;200/' -e s'/PatternChatAndEmail=.*/PatternChatAndEmail=3;3;2;2;100;670;0;800;200/' /etc/mce/mce.ini
-				echo "Soft vibration profile Loaded" 
-				run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Rebooting!"
-                /sbin/reboot 
+				echo "Hard vibration profile Loaded" 
 				;;
 		'-'[Dd] ) 
 		        echo "Dafault" 
 				sed -i -e s'/PatternIncomingCall=.*/PatternIncomingCall=1;3;0;0;30;970;0;1000;180/' -e s'/PatternIncomingMessage=.*/PatternIncomingMessage=3;3;2;2;30;470;0;500;154/' -e s'/PatternChatAndEmail=.*/PatternChatAndEmail=4;3;1;1;30;360;0;100;154/' /etc/mce/mce.ini
-				echo "Soft vibration profile Loaded" 
-				run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Rebooting!"
-                /sbin/reboot   
+				echo "Default vibration profile Loaded" 
 				;;
 		*)     echo "Invalid input for help type --help"
 		       ;;
 			   
-		'--'[help] )
+		'--help' )
 		       echo "Load vibration profiles with sh data.sh and the specific letter -S stands for soft -H for hard and -D for default" 
                ;;			   
 esac 
 
-    
+stop mce
+sleep 1
+start mce
+run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"Restarted mce.ini!" 
